# Polar Bear
<img src="https://raw.githubusercontent.com/regonn/polar_bear/master/data/polar_bear.png" width="300" />

:panda_face: -> cleansing -> polar bear!! ʕ·ᴥ·　ʔ

[![MIT License](http://img.shields.io/badge/license-MIT-blue.svg?style=flat)](https://github.com/regonn/polar_bear/blob/master/LICENSE.txt)

Get Started
--------------
- [Tutorial Notebook](https://github.com/regonn/polar_bear/blob/master/examples/polar_bear_tutorials.ipynb)
